@@ -11,15 +11,15 @@ from shapash.utils.transform import inverse_transform, apply_postprocessing
 from shapash.utils.transform import adapt_contributions
 from shapash.utils.utils import get_host_name
 from shapash.utils.threading import CustomThread
-from shapash.utils.shap_backend import shap_contributions, check_explainer
+from shapash.utils.shap_backend import shap_contributions, check_explainer, get_shap_interaction_values
 from shapash.utils.check import check_model, check_label_dict, check_ypred, check_contribution_object,\
-                                check_postprocessing, check_features_name
+    check_postprocessing, check_features_name
 from shapash.manipulation.select_lines import keep_right_contributions
 from .smart_state import SmartState
 from .multi_decorator import MultiDecorator
 from .smart_plotter import SmartPlotter
 from .smart_predictor import SmartPredictor
-from shapash.utils.model import predict_proba
+from shapash.utils.model import predict_proba, predict
 
 logging.basicConfig(level=logging.INFO)
 
@@ -101,14 +101,14 @@ class SmartExplainer:
     label_dict specify the labels of target (classification).
     """
 
-    def __init__(self, features_dict={}, label_dict=None):
-        if isinstance(features_dict, dict) == False:
+    def __init__(self, features_dict={}, label_dict=None, title_story: str = None):
+        if isinstance(features_dict, dict) is False:
             raise ValueError(
                 """
                 features_dict must be a dict
                 """
             )
-        if label_dict is not None and isinstance(label_dict, dict) == False:
+        if label_dict is not None and isinstance(label_dict, dict) is False:
             raise ValueError(
                 """
                 label_dict must be a dict
@@ -117,9 +117,13 @@ class SmartExplainer:
         self.features_dict = features_dict
         self.label_dict = label_dict
         self.plot = SmartPlotter(self)
+        if title_story is not None:
+            self.title_story = title_story
+        else:
+            self.title_story = ''
 
-
-    def compile(self, x, model, explainer=None, contributions=None, y_pred=None, preprocessing=None, postprocessing=None):
+    def compile(self, x, model, explainer=None, contributions=None, y_pred=None,
+                preprocessing=None, postprocessing=None, title_story: str = None):
         """
         The compile method is the first step to understand model and prediction. It performs the sorting
         of contributions, the reverse preprocessing steps and performs all the calculations necessary for
@@ -143,7 +147,7 @@ class SmartExplainer:
             single or multiple contributions (multi-class) to handle.
             if pandas.Dataframe, the index and columns should be share with the prediction set.
             if np.ndarray, index and columns will be generated according to x dataset
-        y_pred : pandas.Series, optional (default: None)
+        y_pred : pandas.Series or pandas.DataFrame, optional (default: None)
             Prediction values (1 column only).
             The index must be identical to the index of x_pred.
             This is an interesting parameter for more explicit outputs. Shapash lets users define their own predict,
@@ -174,6 +178,9 @@ class SmartExplainer:
             }
 
             Only one transformation by features is possible.
+        title_story: str (default: None)
+            The default title is empty. You can specify a custom title
+            which can be used the webapp, or other methods
 
         Example
         --------
@@ -217,8 +224,10 @@ class SmartExplainer:
         )
         self.features_imp = None
         self.features_desc = self.check_features_desc()
+        if title_story is not None:
+            self.title_story = title_story
 
-    def add(self, y_pred=None, label_dict=None, features_dict=None):
+    def add(self, y_pred=None, label_dict=None, features_dict=None, title_story: str = None):
         """
         add method allows the user to add a label_dict, features_dict
         or y_pred without compiling again (and it can last a few moments).
@@ -235,29 +244,34 @@ class SmartExplainer:
             Dictionary mapping integer labels to domain names.
         features_dict: dict, optional (default: None)
             Dictionary mapping technical feature names to domain names.
+        title_story: str (default: None)
+            The default title is empty. You can specify a custom title
+            which can be used the webapp, or other methods
         """
         if y_pred is not None:
             self.y_pred = self.check_y_pred(y_pred)
         if label_dict is not None:
-            if isinstance(label_dict, dict) == False:
+            if isinstance(label_dict, dict) is False:
                 raise ValueError(
                     """
-                    label_dict must be a dict  
+                    label_dict must be a dict
                     """
                 )
             self.label_dict = label_dict
             self.check_label_dict()
             self.inv_label_dict = {v: k for k, v in self.label_dict.items()}
         if features_dict is not None:
-            if isinstance(features_dict, dict) == False:
+            if isinstance(features_dict, dict) is False:
                 raise ValueError(
                     """
-                    features_dict must be a dict  
+                    features_dict must be a dict
                     """
                 )
             self.features_dict = features_dict
             self.check_features_dict()
             self.inv_features_dict = {v: k for k, v in self.features_dict.items()}
+        if title_story is not None:
+            self.title_story = title_story
 
     def choose_state(self, contributions):
         """
@@ -315,6 +329,37 @@ class SmartExplainer:
         check_contribution_object(self._case, self._classes, contributions)
         return self.state.validate_contributions(contributions, self.x_init)
 
+    def get_interaction_values(self, n_samples_max=None, selection=None):
+        """
+        Compute shap interaction values for each row of x_init.
+        This function is only available for explainer of type TreeExplainer (used for tree based models).
+        Please refer to the official tree shap paper for more information : https://arxiv.org/pdf/1802.03888.pdf
+
+        Parameters
+        ----------
+        n_samples_max : int, optional
+            Limit the number of points for which we compute the interactions.
+        selection : list, optional
+            Contains list of index, subset of the input DataFrame that we want to plot
+
+        Returns
+        -------
+        np.ndarray
+            Shap interaction values for each sample as an array of shape (# samples x # features x # features).
+        """
+        x = copy.deepcopy(self.x_init)
+
+        if selection:
+            x = x.loc[selection]
+
+        if hasattr(self, 'x_interaction'):
+            if self.x_interaction.equals(x[:n_samples_max]):
+                return self.interaction_values
+
+        self.x_interaction = x[:n_samples_max]
+        self.interaction_values = get_shap_interaction_values(self.x_interaction, self.explainer)
+        return self.interaction_values
+
     def apply_preprocessing(self, contributions, preprocessing=None):
         """
         Reconstruct contributions for original features, taken into account a preprocessing.
@@ -359,7 +404,7 @@ class SmartExplainer:
             for key in postprocessing.keys():
                 dict_postprocess = postprocessing[key]
                 if dict_postprocess['type'] in {'prefix', 'suffix'} \
-                    and pd.api.types.is_numeric_dtype(self.x_pred[key]):
+                        and pd.api.types.is_numeric_dtype(self.x_pred[key]):
                     modif = True
         return modif
 
@@ -588,7 +633,6 @@ class SmartExplainer:
             positive=None,
             max_contrib=None
     ):
-
         """
         The filter method is an important method which allows to summarize the local explainability
         by using the user defined parameters which correspond to its use case.
@@ -663,7 +707,7 @@ class SmartExplainer:
         """
         dict_to_save = {}
         for att in self.__dict__.keys():
-            if isinstance(getattr(self, att), (list, dict, pd.DataFrame, pd.Series, type(None))) or att == "model":
+            if isinstance(getattr(self, att), (list, dict, pd.DataFrame, pd.Series, type(None), bool)) or att == "model":
                 dict_to_save.update({att: getattr(self, att)})
         save_pickle(dict_to_save, path)
 
@@ -694,14 +738,17 @@ class SmartExplainer:
                 "pickle file must contain dictionary"
             )
 
-
     def predict_proba(self):
         """
         The predict_proba compute the proba values for each x_init row
         """
         self.proba_values = predict_proba(self.model, self.x_init, self._classes)
 
-
+    def predict(self):
+        """
+        The predict method computes the model output for each x_init row and stores it in y_pred attribute
+        """
+        self.y_pred = predict(self.model, self.x_init)
 
     def to_pandas(
             self,
@@ -750,7 +797,7 @@ class SmartExplainer:
         --------
         >>> summary_df = xpl.to_pandas(max_contrib=2,proba=True)
         >>> summary_df
-        	pred	proba	    feature_1	value_1	    contribution_1	feature_2	value_2	    contribution_2
+            pred	proba	    feature_1	value_1	    contribution_1	feature_2	value_2	    contribution_2
         0	0	    0.756416	Sex	        1.0	        0.322308	    Pclass	    3.0	        0.155069
         1	3	    0.628911	Sex	        2.0	        0.585475	    Pclass	    1.0	        0.370504
         2	0	    0.543308	Sex	        2.0	        -0.486667	    Pclass	    3.0	        0.255072
@@ -789,10 +836,10 @@ class SmartExplainer:
             proba_values = None
 
         y_pred, summary = keep_right_contributions(self.y_pred, self.data['summary'],
-                                                           self._case, self._classes,
-                                                           self.label_dict, proba_values)
+                                                   self._case, self._classes,
+                                                   self.label_dict, proba_values)
 
-        return pd.concat([y_pred,summary], axis=1)
+        return pd.concat([y_pred, summary], axis=1)
 
     def compute_features_import(self, force=False):
         """
@@ -822,7 +869,7 @@ class SmartExplainer:
         """
         self.smartapp = SmartApp(self)
 
-    def run_app(self, port: int = None, host: str = None) -> CustomThread:
+    def run_app(self, port: int = None, host: str = None, title_story: str = None) -> CustomThread:
         """
         run_app method launches the interpretability web app associated with the shapash object.
         run_app method can be used directly in a Jupyter notebook
@@ -838,7 +885,10 @@ class SmartExplainer:
             for your webapp.
         host: str (default: None)
             The default host is '0.0.0.0'. You can specify a custom
-            ip address for your app
+            ip address for your webapp
+        title_story: str (default: None)
+            The default title is empty. You can specify a custom title
+            for your webapp (can be reused in other methods like in a report, ...)
 
         Returns
         -------
@@ -850,10 +900,11 @@ class SmartExplainer:
         >>> app = xpl.run_app()
         >>> app.kill()
         """
+
+        if title_story is not None:
+            self.title_story = title_story
         if self.y_pred is None:
-            raise ValueError(
-                "You have to specify y_pred argument. Please use add() or compile() method"
-            )
+            self.predict()
         if hasattr(self, '_case'):
             self.smartapp = SmartApp(self)
             if host is None:
@@ -907,14 +958,14 @@ class SmartExplainer:
             raise ValueError("""SmartPredictor need an explainer, please compile without contributions or specify  the
                                         explainer used. Make change in compile() step""")
 
-        self.features_types = {features : str(self.x_pred[features].dtypes) for features in self.x_pred.columns}
+        self.features_types = {features: str(self.x_pred[features].dtypes) for features in self.x_pred.columns}
 
         listattributes = ["features_dict", "model", "columns_dict", "explainer", "features_types",
-                            "label_dict", "preprocessing", "postprocessing"]
+                          "label_dict", "preprocessing", "postprocessing"]
 
         params_smartpredictor = [self.check_attributes(attribute) for attribute in listattributes]
 
-        if not hasattr(self,"mask_params"):
+        if not hasattr(self, "mask_params"):
             self.mask_params = {
                 "features_to_hide": None,
                 "threshold": None,
