@@ -13,7 +13,7 @@ from shapash.utils.shap_backend import check_explainer, shap_contributions
 from shapash.manipulation.select_lines import keep_right_contributions
 from shapash.utils.model import predict_proba
 from shapash.utils.io import save_pickle
-from shapash.utils.transform import apply_preprocessing, apply_postprocessing
+from shapash.utils.transform import apply_preprocessing, apply_postprocessing, preprocessing_tolist
 from shapash.manipulation.filters import hide_contributions
 from shapash.manipulation.filters import cap_contributions
 from shapash.manipulation.filters import sign_contributions
@@ -117,7 +117,6 @@ class SmartPredictor :
         self.model = model
         self._case, self._classes = self.check_model()
         self.explainer = self.check_explainer(explainer)
-        check_preprocessing_options(preprocessing)
         self.preprocessing = preprocessing
         self.check_preprocessing()
         self.features_dict = features_dict
@@ -128,10 +127,12 @@ class SmartPredictor :
         self.mask_params = mask_params
         self.check_mask_params()
         self.postprocessing = postprocessing
+        list_preprocessing = preprocessing_tolist(self.preprocessing)
         check_consistency_model_features(self.features_dict, self.model, self.columns_dict,
                                          self.features_types, self.mask_params, self.preprocessing,
-                                         self.postprocessing)
+                                         self.postprocessing, list_preprocessing)
         check_consistency_model_label(self.columns_dict, self.label_dict)
+        self._drop_option = check_preprocessing_options(columns_dict, features_dict, preprocessing, list_preprocessing)
 
     def check_model(self):
         """
@@ -292,7 +293,10 @@ class SmartPredictor :
 
         assert all(column in self.features_types.keys() for column in x.columns)
         if not all([str(x[feature].dtypes) == self.features_types[feature] for feature in x.columns]):
-            raise ValueError("Types of features in x doesn't match with the expected one in features_types.")
+            raise ValueError("""
+                  Types of features in x doesn't match with the expected one in features_types.
+                  x input must be initial dataset without preprocessing applied.
+                  """)
         return x
 
     def check_ypred(self, ypred=None):
@@ -365,7 +369,12 @@ class SmartPredictor :
         """
         Check if contributions and prediction set match in terms of shape and index.
         """
-        if not self.state.check_contributions(contributions, self.data["x"], features_names=False):
+        if self._drop_option is not None:
+            x = self.data["x"][self.data["x"].columns.difference(self._drop_option["features_to_drop"])]
+        else:
+            x = self.data["x"]
+
+        if not self.state.check_contributions(contributions, x, features_names=False):
             raise ValueError(
                 """
                 Prediction set and contributions should have exactly the same number of lines
@@ -374,6 +383,7 @@ class SmartPredictor :
                 """
             )
 
+
     def clean_data(self, x):
         """
         Clean data stored if x is defined and not None.
@@ -620,10 +630,20 @@ class SmartPredictor :
         if not hasattr(self, "data"):
             raise ValueError("You have to specify dataset x and y_pred arguments. Please use add_input() method.")
 
+        if self._drop_option is not None:
+            x_preprocessed = self.data["x_postprocessed"][self._drop_option["columns_dict_op"].values()]
+            columns_dict =self._drop_option["columns_dict_op"]
+            features_dict = self._drop_option["features_dict_op"]
+        else:
+            x_preprocessed = self.data["x_postprocessed"]
+            columns_dict = self.columns_dict
+            features_dict = self.features_dict
+
+
         self.summary = assign_contributions(
             rank_contributions(
                 self.data["contributions"],
-                self.data["x_postprocessed"]
+                x_preprocessed
             )
         )
         # Apply filter method with mask_params attributes parameters
@@ -634,8 +654,8 @@ class SmartPredictor :
                                          self.summary['var_dict'],
                                          self.summary['x_sorted'],
                                          self.mask,
-                                         self.columns_dict,
-                                         self.features_dict)
+                                         columns_dict,
+                                         features_dict)
 
         # Matching with y_pred
         return pd.concat([self.data["ypred"], self.data['summary']], axis=1)
